@extends('themes.base.layout')
@section('title', 'Gallery Admin')

@section('breadcrumb')
    <li class="breadcrumb-item"><a href="{{ route('home') }}"><i class="fa fa-fw fa-home"></i></a></li>
    <li class="breadcrumb-item"><a href="{{ route('admin') }}">@lang('navigation.breadcrumb.admin')</a></li>
    <li class="breadcrumb-item"><a href="{{ route('albums.index') }}">@lang('navigation.breadcrumb.albums')</a></li>
    <li class="breadcrumb-item"><a href="{{ route('albums.show', ['id' => $album->id]) }}">{{ $album->name }}</a></li>
    <li class="breadcrumb-item active">@lang('navigation.breadcrumb.edit_album')</li>
@endsection

@section('content')
    <div class="container">
        <div class="row">
            <div class="col">
                <h1>@lang('admin.edit_album', ['album_name' => $album->name])</h1>
                <p>@lang('admin.edit_album_intro')</p>
                <p>@lang('admin.edit_album_intro2', ['album_name' => $album->name])</p>
                <hr/>

                <form method="post" action="{{ route('albums.update', [$album->id]) }}">
                    {{ csrf_field() }}
                    {{ method_field('PUT') }}

                    <div class="form-group{{ $errors->has('name') ? ' has-danger' : '' }}">
                        <label for="album-name" class="control-label">@lang('forms.name_label')</label>
                        <input type="text" id="album-name" class="form-control" name="name" value="{{ old('name') }}" />

                        @if ($errors->has('name'))
                            <div class="form-control-feedback">
                                <strong>{{ $errors->first('name') }}</strong>
                            </div>
                        @endif
                    </div>

                    <div class="form-group{{ $errors->has('description') ? ' has-danger' : '' }}">
                        <label for="album-description" class="control-label" name="name">@lang('forms.description_label')</label>
                        <textarea class="form-control" id="album-description" rows="5" name="description">{{ old('description') }}</textarea>

                        @if ($errors->has('description'))
                            <div class="form-control-feedback">
                                <strong>{{ $errors->first('description') }}</strong>
                            </div>
                        @endif
                    </div>

                    <div class="form-group">
                        <label class="form-control-label" for="parent-album">@lang('forms.parent_album_label')</label>
                        <select class="form-control" name="parent_album_id" id="parent-album">
                            <option value="">@lang('forms.parent_album_placeholder')</option>
                            @foreach ($parent_albums as $key => $value)
                                <option value="{{ $key }}"{{ $key == $album->id || $value->isChildOf($album) ? ' disabled="disabled"' : '' }}{{ $key == old('parent_album_id') ? ' selected="selected"' : '' }}>{{ $value->display_name }}{{ $key == old('parent_album_id') ? ' ' . trans('forms.select_current_text') : '' }}</option>
                            @endforeach
                        </select>
                    </div>

                    <div class="text-right">
                        <a href="{{ route('albums.show', ['id' => $album->id]) }}" class="btn btn-link">@lang('forms.cancel_action')</a>
                        <button type="submit" class="btn btn-success"><i class="fa fa-fw fa-check"></i> @lang('forms.save_action')</button>
                    </div>
                </form>
            </div>
        </div>
    </div>
@endsection